==============
data for NP
==============

This directory contains alignments and preferences for influenza nucleoprotein to be used in some of the tests.

The preferences come from `Doud et al (2015)`_, and are written in several different formats to test the preferences parser.

The alignment is a small set of NP codon sequences.

The tree is built with ``RAxML`` on the alignment.


.. _`Doud et al (2015)`: https://dx.doi.org/10.1093/molbev/msv167
.. _`Kitzman et al (2014)`: http://www.nature.com/nmeth/journal/v12/n3/full/nmeth.3223.html
.. _`Bloom (2016)`: http://dx.doi.org/10.1101/037689
.. _`MAFFT`: http://mafft.cbrc.jp/alignment/software/
